<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>QuickLaunchButton</name>
    <message>
        <source>Move left</source>
        <translation>左移</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation>右移</translation>
    </message>
    <message>
        <source>Remove from quicklaunch</source>
        <translation>从快速启动删除</translation>
    </message>
</context>
<context>
    <name>RazorQuickLaunch</name>
    <message>
        <source>Drop Error</source>
        <translation>出现错误</translation>
    </message>
    <message>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>文件/URL &apos;%1&apos; 暂时无法被嵌入到快速启动</translation>
    </message>
</context>
</TS>